package com.sun.jndi.cosnaming;

import java.util.StringTokenizer;
import com.sun.jndi.toolkit.url.UrlUtil;
import java.net.MalformedURLException;
import javax.naming.NamingException;
import javax.naming.Name;
import java.util.Vector;

public final class IiopUrl
{
    private static final int DEFAULT_IIOPNAME_PORT = 9999;
    private static final int DEFAULT_IIOP_PORT = 900;
    private static final String DEFAULT_HOST = "localhost";
    private Vector<IiopUrl.Address> addresses;
    private String stringName;
    
    public Vector<IiopUrl.Address> getAddresses() {
        return this.addresses;
    }
    
    public String getStringName() {
        return this.stringName;
    }
    
    public Name getCosName() throws NamingException {
        return CNCtx.parser.parse(this.stringName);
    }
    
    public IiopUrl(String str) throws MalformedURLException {
        int n;
        int beginIndex;
        if (str.startsWith("iiopname://")) {
            n = false;
            beginIndex = 11;
        }
        else if (str.startsWith("iiop://")) {
            n = true;
            beginIndex = 7;
        }
        else {
            throw new MalformedURLException("Invalid iiop/iiopname URL: " + str);
        }
        int n2 = str.indexOf(47, beginIndex);
        if (n2 < 0) {
            n2 = str.length();
            this.stringName = "";
        }
        else {
            this.stringName = UrlUtil.decode(str.substring(n2 + 1));
        }
        this.addresses = new Vector(3);
        if (!(n == 0)) {
            this.addresses.addElement(new IiopUrl.Address(str.substring(beginIndex, n2), (boolean)n));
        }
        else {
            StringTokenizer o = new StringTokenizer(str.substring(beginIndex, n2), ",");
            while (o.hasMoreTokens()) {
                this.addresses.addElement(new IiopUrl.Address(o.nextToken(), (boolean)n));
            }
            if (this.addresses.size() == 0) {
                this.addresses.addElement(new IiopUrl.Address("", (boolean)n));
            }
        }
    }
    
    public static class Address
    {
        public int port;
        public int major;
        public int minor;
        public String host;
        
        public Address(String s, boolean b) throws MalformedURLException {
            this.port = -1;
            int index;
            int beginIndex;
            if (b || (index = s.indexOf(64)) < 0) {
                this.major = 1;
                this.minor = 0;
                beginIndex = 0;
            }
            else {
                int index2 = s.indexOf(46);
                if (index2 < 0) {
                    throw new MalformedURLException("invalid version: " + s);
                }
                try {
                    this.major = Integer.parseInt(s.substring(0, index2));
                    this.minor = Integer.parseInt(s.substring(index2 + 1, index));
                }
                catch (NumberFormatException ex) {
                    throw new MalformedURLException("Nonnumeric version: " + s);
                }
                beginIndex = index + 1;
            }
            int endIndex = s.indexOf(47, beginIndex);
            if (endIndex < 0) {
                endIndex = s.length();
            }
            int n;
            if (s.startsWith("[", beginIndex)) {
                int index4 = s.indexOf(93, beginIndex + 1);
                if (index4 < 0 || index4 > endIndex) {
                    throw new IllegalArgumentException("IiopURL: name is an Invalid URL: " + s);
                }
                this.host = s.substring(beginIndex, index4 + 1);
                n = index4 + 1;
            }
            else {
                int index3 = s.indexOf(58, beginIndex);
                index3 = ((index3 < 0 || index3 > endIndex) ? endIndex : index3);
                if (beginIndex < index3) {
                    this.host = s.substring(beginIndex, index3);
                }
                n = index3;
            }
            if (n + 1 < endIndex) {
                if (s.startsWith(":", n)) {
                    ++n;
                    this.port = Integer.parseInt(s.substring(n, endIndex));
                }
                else {
                    throw new IllegalArgumentException("IiopURL: name is an Invalid URL: " + s);
                }
            }
            if ("".equals(this.host) || this.host == null) {
                this.host = "localhost";
            }
            if (this.port == -1) {
                this.port = (b ? 900 : 9999);
            }
        }
    }
}
